from setuptools import setup, find_packages



setup(
    name = 'spdividecalc',
    version = '0.0.1',
    description = 'a very basic divide function',
    long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url='',
    author='Saurabh Pratap Singh',
    author_email='singhsaurabhpratap514@gmail.com',
    license='MIT',
    keywords='',
    packages=find_packages(),
)